#!/bin/sh
#
# eyedb-postinstall.sh
#
#

prefix=/usr
exec_prefix=/usr
bindir=/usr/bin
sbindir=/usr/sbin
eyedb_databasedir=/var/lib/lib/eyedb/db
eyedb_pipedir=/var/lib/lib/eyedb/pipes
eyedb_tmpdir=/var/lib/lib/eyedb/tmp

PROGNAME=

decrypt_options()
{
    for arg in $@
    do
      case $arg in
	  \-help | \-h)
          usage
	  exit 0
	  ;;
	  *)
          usage
	  exit 2
	  ;;
      esac
   done
}

usage()
{
    echo "$PROGNAME creates the EYEDBDBM system database."
    echo
    echo "This script must be run after installing EyeDB in a previously empty directory."
    echo
    echo "usage: $PROGNAME [OPTION]"
    echo
    echo "Options:"
    echo "  -h, --help               display this help and exit"
    echo
}

ECHO()
{
    echo "$PROGNAME: $*"
}

create_directories() {
    [ ! -d $eyedb_databasedir ] && mkdir -p $eyedb_databasedir
    [ ! -d $eyedb_pipedir ] && mkdir -p $eyedb_pipedir
    [ ! -d $eyedb_tmpdir ] && mkdir -p $eyedb_tmpdir
    chmod a+w $eyedb_tmpdir
}

start_server()
{
    echo ==== Starting EyeDB server
    $sbindir/eyedbctl start --creating-dbm --nod
}

create_dbm()
{
    echo ==== Creating EYEDBDBM database
    $bindir/eyedbadmin dbmcreate --strict-unix=@
    echo ==== Setting EYEDBDBM database permissions
    $bindir/eyedbadmin dbaccess EYEDBDBM r --user=@
}

stop_server()
{
    echo ==== Stopping EyeDB server
    $sbindir/eyedbctl stop
}

clean_exit()
{
    SAVED_STATUS=$?
    # Check if EyeDB is running, and stop it if running
    if $sbindir/eyedbctl status > /dev/null 2>&1 ; then
	$sbindir/eyedbctl stop
    fi
    exit $SAVED_STATUS
}

PROGNAME=`basename $0`
decrypt_options $*

set -e
trap clean_exit 0

create_directories

start_server

sleep 4

create_dbm

stop_server
